Type Definition subplotlib::prelude::StepResult
source · Expand description
Result type using StepError.
This is useful for use in situations where you
might use #[throws(...)]. Step functions
generated using the step macro will
automatically set this as their return type by means of #[throws(StepResult)].