pub fn call( ___context___: &ScenarioContext, filename: &Path, data: &str, ) -> StepResult
Call this step function from another.
If you want to call this step function from another, you will need to do something like this:
#[step] #[context("Datadir")] fn defer_to_file_contains(context: &ScenarioContext) { //... file_contains::call(context, filename, data)?; // ... }