Function subplotlib::steplibrary::files::file_does_not_exist::call
source · pub fn call(___context___: &ScenarioContext, filename: &Path) -> StepResultExpand description
Call this step function from another.
If you want to call this step function from another, you will need to do something like this:
ⓘ
#[step]
#[context("Datadir")]
fn defer_to_file_does_not_exist(context: &ScenarioContext) {
//...
file_does_not_exist::call(context, filename)?;
// ...
}