pub fn call(___context___: &ScenarioContext, filenames: &str) -> StepResult
Call this step function from another.

If you want to call this step function from another, you will need to do something like this:

#[step]
#[context("Datadir")]
fn defer_to_only_these_exist(context: &ScenarioContext) {
    //...
    only_these_exist::call(context, filenames)?;
    // ...
}