Module path_exists

Module path_exists 

Check that a directory exists

then directory {path} exists

This ensures that the given path exists in the data directory for the scenario and that it is a directory itself.

Functions

call
Call this step function from another.