pub fn call(
___context___: &ScenarioContext,
embedded_file: SubplotDataFile,
) -> StepResultExpand description
Call this step function from another.
If you want to call this step function from another, you will need to do something like this:
ⓘ
#[step]
#[context("Datadir")]
#[context("Runcmd")]
fn defer_to_create_executable_from_embedded(context: &ScenarioContext) {
//...
create_executable_from_embedded::call(context, embedded_file)?;
// ...
}