Module subplotlib::steplibrary::files::file_contains
source · Expand description
Check if a file contains a given sequence of characters
then file (?P<filename>\S+) contains "(?P<data>.*)"
This will load the content of the named file and ensure it contains the given string. Note: this assumes everything is utf-8 encoded. If not, things will fail.