Check if a file’s content matches the given regular expression
then file (?P<filename>\S+) matches regex /(?P<regex>.*)/
This will load the content of th enamed file and ensure it contains data which matches the given regular expression. This step will fail if the file is not utf-8 encoded, or if the regex fails to compile