Module subplotlib::steplibrary::files::path_is_empty
source · Expand description
Check that a directory exists and is empty
then directory {path} is empty
This checks that the given path inside the data directory exists and is an empty directory itself.